@@ -36,7 +36,7 @@ cgettext = gettext.gettext
 
 # Tell gettext where to find localized strings.
 #
-localedir = os.path.join ("/home/jd/checkout/orca/bld", "share", "locale")
+localedir = os.path.join ("/home/dev/checkout/gnome/orca/bld", "share", "locale")
 gettext.bindtextdomain ("orca", localedir)
 gettext.textdomain("orca")
 
@@ -57,15 +57,16 @@ def C_(ctx, s):
 def setModuleLocale(moduleName, newLocale=None):
     global _, ngettext, cgettext
 
-    try:
+    if not newLocale:
+        _ = gettext.gettext
+        ngettext = gettext.ngettext
+        cgettext = gettext.gettext
+    else:
         translation = gettext.translation('orca', localedir, languages=[newLocale])
         _ = translation.gettext
         ngettext = translation.ngettext
         cgettext = translation.gettext
-    except:
-        _ = gettext.gettext
-        ngettext = gettext.ngettext
-        cgettext = gettext.gettext
+
     module = sys.modules.get(moduleName)
     if module:
         imp.reload(module)
