@@ -160,6 +160,8 @@ class ScriptManager:
                 debug.println(
                     debug.LEVEL_FINE, "Could not import %s.py" % moduleName)
                 continue
+            except OSError:
+                debug.examineProcesses()
 
             debug.println(debug.LEVEL_FINE, "Found %s.py" % moduleName)
             try:
@@ -251,6 +253,7 @@ class ScriptManager:
                 appScript.registerEventListeners()
         except:
             msg = "WARNING: Exception getting app script."
+            debug.printException(debug.LEVEL_ALL)
             debug.println(debug.LEVEL_WARNING, msg)
             appScript = self.getDefaultScript()
 
